@@ -1,9 +1,9 @@
-pub use naia_client::{ClientConfig, OwnedEntity, Random};
+pub use naia_client::*;
 
-pub mod components;
 pub mod events;
 
 mod client;
+mod commands;
 mod plugin;
 mod resource;
 mod stage;
@@ -11,5 +11,6 @@ mod state;
 mod systems;
 
 pub use client::Client;
+pub use commands::CommandsExt;
 pub use plugin::Plugin;
 pub use stage::Stage;
