@@ -1,3 +1,5 @@
+use std::default::Default;
+
 use naia_bevy_shared::Flag;
 
 pub struct ClientResource {
@@ -6,8 +8,8 @@ pub struct ClientResource {
     pub disconnector: Flag,
 }
 
-impl ClientResource {
-    pub fn new() -> Self {
+impl Default for ClientResource {
+    fn default() -> Self {
         Self {
             ticker: Flag::new(),
             connector: Flag::new(),
