@@ -1,37 +1,35 @@
 use std::marker::PhantomData;
 
-use bevy::ecs::{
+use bevy_ecs::{
     system::{SystemMeta, SystemParamFetch, SystemParamState},
     world::World,
 };
 
-use naia_client::ProtocolType;
+use naia_client::shared::{ChannelIndex, Protocolize};
 
 use super::client::Client;
 
 // State
 
-pub struct State<P: ProtocolType> {
+pub struct State<P: Protocolize, C: ChannelIndex> {
     phantom_p: PhantomData<P>,
+    phantom_c: PhantomData<C>,
 }
 
 // SAFE: only local state is accessed
-unsafe impl<P: ProtocolType> SystemParamState for State<P> {
-    type Config = ();
-
-    fn init(_world: &mut World, _system_state: &mut SystemMeta, _config: Self::Config) -> Self {
-        State {
+unsafe impl<P: Protocolize, C: ChannelIndex> SystemParamState for State<P, C> {
+    fn init(_world: &mut World, _system_meta: &mut SystemMeta) -> Self {
+        Self {
             phantom_p: PhantomData,
+            phantom_c: PhantomData,
         }
     }
-
-    fn apply(&mut self, _world: &mut World) {}
-
-    fn default_config() {}
 }
 
-impl<'world, 'state, P: ProtocolType> SystemParamFetch<'world, 'state> for State<P> {
-    type Item = Client<'world, P>;
+impl<'world, 'state, P: Protocolize, C: ChannelIndex> SystemParamFetch<'world, 'state>
+    for State<P, C>
+{
+    type Item = Client<'world, P, C>;
 
     #[inline]
     unsafe fn get_param(
